=== modified file 'drizzled/plugin/table_function.cc'
--- drizzled/plugin/table_function.cc	2010-03-16 23:42:10 +0000
+++ drizzled/plugin/table_function.cc	2010-03-17 19:18:40 +0000
@@ -41,7 +41,7 @@
   drizzled::message::Table::StorageEngine *engine;
   drizzled::message::Table::TableOptions *table_options;
 
-  proto.set_name(identifier.getTableName());
+  proto.set_name(getTableLabel());
   proto.set_type(drizzled::message::Table::FUNCTION);
   proto.set_creation_timestamp(0);
   proto.set_update_timestamp(0);

=== modified file 'drizzled/plugin/table_function.h'
--- drizzled/plugin/table_function.h	2010-02-18 17:24:08 +0000
+++ drizzled/plugin/table_function.h	2010-03-17 19:18:40 +0000
@@ -44,6 +44,20 @@
 namespace plugin
 {
 
+// Not thread safe, but plugins are just loaded in a single thread right
+// now.
+static const char *local_string_append(const char *arg1, const char *arg2)
+{
+  static char buffer[1024];
+  char *buffer_ptr= buffer;
+  strcpy(buffer_ptr, arg1);
+  buffer_ptr+= strlen(arg1);
+  buffer_ptr[0]= '-';
+  buffer_ptr++;
+  strcpy(buffer_ptr, arg2);
+
+  return buffer;
+}
 
 class TableFunction : public Plugin
 {
@@ -55,6 +69,8 @@
   TableIdentifier identifier;
   std::string local_path;
   std::string local_schema;
+  std::string local_table_name;
+  std::string original_table_label;
 
   void setName(); // init name
 
@@ -62,8 +78,9 @@
 
 public:
   TableFunction(const char *schema_arg, const char *table_arg) :
-    Plugin(table_arg, "TableFunction"),
-    identifier(schema_arg, table_arg)
+    Plugin(local_string_append(schema_arg, table_arg) , "TableFunction"),
+    identifier(schema_arg, table_arg),
+    original_table_label(table_arg)
   {
     init();
   }
@@ -120,9 +137,26 @@
     arg.CopyFrom(proto);
   }
 
+  const std::string &getTableLabel()
+  { 
+    return original_table_label;
+  }
+
+  const std::string &getIdentifierTableName()
+  { 
+    if (local_table_name.empty())
+    {
+      local_table_name= identifier.getTableName();
+      std::transform(local_table_name.begin(), local_table_name.end(),
+                     local_table_name.begin(), ::tolower);
+    }
+
+    return local_table_name;
+  }
+
   const std::string &getSchemaHome()
   { 
-    if (local_schema.length() == 0)
+    if (local_schema.empty())
     {
       local_schema= identifier.getSchemaName();
       std::transform(local_schema.begin(), local_schema.end(),
@@ -134,7 +168,7 @@
 
   const std::string &getPath()
   { 
-    if (local_path.length() == 0)
+    if (local_path.empty())
     {
       local_path= identifier.getPath();
       std::transform(local_path.begin(), local_path.end(),

=== modified file 'drizzled/table_function_container.cc'
--- drizzled/table_function_container.cc	2010-02-05 08:11:15 +0000
+++ drizzled/table_function_container.cc	2010-03-17 19:18:40 +0000
@@ -39,7 +39,7 @@
 }
 
 void TableFunctionContainer::getNames(const string &predicate,
-				      std::set<std::string> &set_of_names)
+                                      std::set<std::string> &set_of_names)
 {
   for (ToolMap::iterator it= table_map.begin();
        it != table_map.end();
@@ -51,12 +51,12 @@
     {
       if (not predicate.compare(tool->getSchemaHome()))
       {
-        set_of_names.insert(tool->getName());
+        set_of_names.insert(tool->getTableLabel());
       }
     }
     else
     {
-      set_of_names.insert(tool->getName());
+      set_of_names.insert(tool->getTableLabel());
     }
   }
 }

=== added directory 'plugin/information_schema_dictionary'
=== added file 'plugin/information_schema_dictionary/check_constraints.cc'
--- plugin/information_schema_dictionary/check_constraints.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/check_constraints.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,69 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+CheckConstraints::CheckConstraints() :
+  InformationSchema("CHECK_CONSTRAINTS")
+{
+  add_field("CONSTRAINT_CATALOG");
+  add_field("CONSTRAINT_SCHEMA");
+  add_field("CONSTRAINT_NAME");
+  add_field("CHECK_CLAUSE");
+}
+
+void CheckConstraints::Generator::fill()
+{
+}
+
+bool CheckConstraints::Generator::nextCore()
+{
+  return false;
+}
+
+bool CheckConstraints::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+CheckConstraints::Generator::Generator(drizzled::Field **arg):
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool CheckConstraints::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/check_constraints.h'
--- plugin/information_schema_dictionary/check_constraints.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/check_constraints.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CHECK_CONSTRAINTS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CHECK_CONSTRAINTS_H
+
+class CheckConstraints : public InformationSchema
+{
+public:
+
+  CheckConstraints();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CHECK_CONSTRAINTS_H */

=== added file 'plugin/information_schema_dictionary/column_domain_usage.cc'
--- plugin/information_schema_dictionary/column_domain_usage.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/column_domain_usage.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,72 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+ColumnDomainUsage::ColumnDomainUsage() :
+  InformationSchema("COLUMN_DOMAIN_USAGE")
+{
+  add_field("DOMAIN_CATALOG");
+  add_field("DOMAIN_SCHEMA");
+  add_field("DOMAIN_NAME");
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("COLUMN_NAME");
+}
+
+void ColumnDomainUsage::Generator::fill()
+{
+}
+
+bool ColumnDomainUsage::Generator::nextCore()
+{
+  return false;
+}
+
+bool ColumnDomainUsage::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+ColumnDomainUsage::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool ColumnDomainUsage::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/column_domain_usage.h'
--- plugin/information_schema_dictionary/column_domain_usage.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/column_domain_usage.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMN_DOMAIN_USAGE_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMN_DOMAIN_USAGE_H
+
+class ColumnDomainUsage : public InformationSchema
+{
+public:
+
+  ColumnDomainUsage();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMN_DOMAIN_USAGE_H */

=== added file 'plugin/information_schema_dictionary/column_privileges.cc'
--- plugin/information_schema_dictionary/column_privileges.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/column_privileges.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,73 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+ColumnPrivileges::ColumnPrivileges() :
+  InformationSchema("COLUMN_PRIVILEGES")
+{
+  add_field("GRANTOR");
+  add_field("GRANTEE");
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("COLUMN_NAME");
+  add_field("PRIVILEGE_TYPE");
+  add_field("IS_GRANTABLE");
+}
+
+void ColumnPrivileges::Generator::fill()
+{
+}
+
+bool ColumnPrivileges::Generator::nextCore()
+{
+  return false;
+}
+
+bool ColumnPrivileges::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+ColumnPrivileges::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool ColumnPrivileges::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/column_privileges.h'
--- plugin/information_schema_dictionary/column_privileges.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/column_privileges.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMN_PRIVILEGES_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMN_PRIVILEGES_H
+
+class ColumnPrivileges : public InformationSchema
+{
+public:
+
+  ColumnPrivileges();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMN_PRIVILEGES_H */

=== added file 'plugin/information_schema_dictionary/columns.cc'
--- plugin/information_schema_dictionary/columns.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/columns.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,89 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+Columns::Columns() :
+  InformationSchema("COLUMNS")
+{
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("COLUMN_NAME");
+  add_field("ORDINAL_POSITION");
+  add_field("COLUMN_DEFAULT");
+  add_field("IS_NULLABLE");
+  add_field("DATA_TYPE");
+  add_field("CHARACTER_MAXIMUM_LENGTH");
+  add_field("CHARACTER_OCTET_LENGTH");
+  add_field("NUMERIC_PRECISION");
+  add_field("NUMERIC_PRECISION_RADIX");
+  add_field("NUMERIC_SCALE");
+  add_field("DATETIME_PRECISION");
+  add_field("CHARACTER_SET_CATALOG");
+  add_field("CHARACTER_SET_SCHEMA");
+  add_field("CHARACTER_SET_NAME");
+  add_field("COLLATION_CATALOG");
+  add_field("COLLATION_SCHEMA");
+  add_field("COLLATION_NAME");
+  add_field("DOMAIN_CATALOG");
+  add_field("DOMAIN_SCHEMA");
+  add_field("DOMAIN_NAME");
+}
+
+
+void Columns::Generator::fill()
+{
+}
+
+bool Columns::Generator::nextCore()
+{
+  return false;
+}
+
+bool Columns::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+Columns::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool Columns::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/columns.h'
--- plugin/information_schema_dictionary/columns.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/columns.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMNS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMNS_H
+
+class Columns : public InformationSchema
+{
+public:
+
+  Columns();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_COLUMNS_H */

=== added file 'plugin/information_schema_dictionary/constraint_column_usage.cc'
--- plugin/information_schema_dictionary/constraint_column_usage.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/constraint_column_usage.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,72 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+ConstraintColumnUsage::ConstraintColumnUsage() :
+  InformationSchema("CONSTRAINT_COLUMN_USAGE")
+{
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("COLUMN_NAME");
+  add_field("CONSTRAINT_CATALOG");
+  add_field("CONSTRAINT_SCHEMA");
+  add_field("CONSTRAINT_NAME");
+}
+
+void ConstraintColumnUsage::Generator::fill()
+{
+}
+
+bool ConstraintColumnUsage::Generator::nextCore()
+{
+  return false;
+}
+
+bool ConstraintColumnUsage::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+ConstraintColumnUsage::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool ConstraintColumnUsage::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/constraint_column_usage.h'
--- plugin/information_schema_dictionary/constraint_column_usage.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/constraint_column_usage.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CONSTRAINT_COLUMN_USAGE_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CONSTRAINT_COLUMN_USAGE_H
+
+class ConstraintColumnUsage : public InformationSchema
+{
+public:
+
+  ConstraintColumnUsage();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CONSTRAINT_COLUMN_USAGE_H */

=== added file 'plugin/information_schema_dictionary/constraint_table_usage.cc'
--- plugin/information_schema_dictionary/constraint_table_usage.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/constraint_table_usage.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,71 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+ConstraintTableUsage::ConstraintTableUsage() :
+  InformationSchema("CONSTRAINT_TABLE_USAGE")
+{
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("CONSTRAINT_CATALOG");
+  add_field("CONSTRAINT_SCHEMA");
+  add_field("CONSTRAINT_NAME");
+}
+
+void ConstraintTableUsage::Generator::fill()
+{
+}
+
+bool ConstraintTableUsage::Generator::nextCore()
+{
+  return false;
+}
+
+bool ConstraintTableUsage::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+ConstraintTableUsage::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool ConstraintTableUsage::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/constraint_table_usage.h'
--- plugin/information_schema_dictionary/constraint_table_usage.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/constraint_table_usage.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CONSTRAINT_TABLE_USAGE_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CONSTRAINT_TABLE_USAGE_H
+
+class ConstraintTableUsage : public InformationSchema
+{
+public:
+
+  ConstraintTableUsage();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_CONSTRAINT_TABLE_USAGE_H */

=== added file 'plugin/information_schema_dictionary/dictionary.cc'
--- plugin/information_schema_dictionary/dictionary.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/dictionary.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,154 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace drizzled;
+
+static CheckConstraints *check_constraints;
+static ColumnDomainUsage *column_domain_usage;
+static ColumnPrivileges *column_privileges;
+static Columns *columns;
+static ConstraintColumnUsage *constraint_column_usage;
+static ConstraintTableUsage *constraint_table_usage;
+static DomainConstraints *domain_constraints;
+static Domains *domains;
+static KeyColumnUsage *key_column_usage;
+static Parameters *parameters;
+static ReferentialConstraints *referential_constraints;
+static Routines *routines;
+static RoutineColumns *routine_columns;
+static Schemata *schemata;
+static TableConstraints *table_constraints;
+static TablePriviledges *table_privileges;
+static Tables *tables;
+static ViewColumnUsage *view_column_usage;
+static ViewTableUsage *view_table_usage;
+static Views *views;
+
+static int init(drizzled::plugin::Registry &registry)
+{
+  check_constraints = new(std::nothrow)CheckConstraints;
+  column_domain_usage = new(std::nothrow)ColumnDomainUsage;
+  column_privileges = new(std::nothrow)ColumnPrivileges;
+  columns = new(std::nothrow)Columns;
+  constraint_column_usage = new(std::nothrow)ConstraintColumnUsage;
+  constraint_table_usage = new(std::nothrow)ConstraintTableUsage;
+  domain_constraints = new(std::nothrow)DomainConstraints;
+  domains = new(std::nothrow)Domains;
+  key_column_usage = new(std::nothrow)KeyColumnUsage;
+  parameters = new(std::nothrow)Parameters;
+  referential_constraints = new(std::nothrow)ReferentialConstraints;
+  routines = new(std::nothrow)Routines;
+  routine_columns = new(std::nothrow)RoutineColumns;
+  schemata = new(std::nothrow)Schemata;
+  table_constraints = new(std::nothrow)TableConstraints;
+  table_privileges = new(std::nothrow)TablePriviledges;
+  tables = new(std::nothrow)Tables;
+  view_column_usage = new(std::nothrow)ViewColumnUsage;
+  view_table_usage = new(std::nothrow)ViewTableUsage;
+  views = new(std::nothrow)Views;
+
+  registry.add(check_constraints);
+  registry.add(column_domain_usage);
+  registry.add(column_privileges);
+  registry.add(columns);
+  registry.add(constraint_column_usage);
+  registry.add(constraint_table_usage);
+  registry.add(domain_constraints);
+  registry.add(domains);
+  registry.add(key_column_usage);
+  registry.add(parameters);
+  registry.add(referential_constraints);
+  registry.add(routines);
+  registry.add(routine_columns);
+  registry.add(schemata);
+  registry.add(table_constraints);
+  registry.add(table_privileges);
+  registry.add(tables);
+  registry.add(view_column_usage);
+  registry.add(view_table_usage);
+  registry.add(views);
+
+  return 0;
+}
+
+static int finalize(drizzled::plugin::Registry &registry)
+{
+  registry.remove(check_constraints);
+  registry.remove(column_domain_usage);
+  registry.remove(column_privileges);
+  registry.remove(columns);
+  registry.remove(constraint_column_usage);
+  registry.remove(constraint_table_usage);
+  registry.remove(domain_constraints);
+  registry.remove(domains);
+  registry.remove(key_column_usage);
+  registry.remove(parameters);
+  registry.remove(referential_constraints);
+  registry.remove(routines);
+  registry.remove(routine_columns);
+  registry.remove(schemata);
+  registry.remove(table_constraints);
+  registry.remove(table_privileges);
+  registry.remove(tables);
+  registry.remove(view_column_usage);
+  registry.remove(view_table_usage);
+  registry.remove(views);
+
+  delete check_constraints;
+  delete column_domain_usage;
+  delete column_privileges;
+  delete columns;
+  delete constraint_column_usage;
+  delete constraint_table_usage;
+  delete domain_constraints;
+  delete domains;
+  delete key_column_usage;
+  delete parameters;
+  delete referential_constraints;
+  delete routines;
+  delete routine_columns;
+  delete schemata;
+  delete table_constraints;
+  delete table_privileges;
+  delete tables;
+  delete view_column_usage;
+  delete view_table_usage;
+  delete views;
+
+  return 0;
+}
+
+DRIZZLE_DECLARE_PLUGIN
+{
+  DRIZZLE_VERSION_ID,
+  "information_schema_dictionary",
+  "1.0",
+  "Brian Aker",
+  "Data Dictionary for ANSI information schema, etc",
+  PLUGIN_LICENSE_GPL,
+  init,
+  finalize,
+  NULL,
+  NULL
+}
+DRIZZLE_DECLARE_PLUGIN_END;

=== added file 'plugin/information_schema_dictionary/dictionary.h'
--- plugin/information_schema_dictionary/dictionary.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/dictionary.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,52 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_H
+
+#include <set>
+
+#include "drizzled/plugin/table_function.h"
+#include "drizzled/plugin/storage_engine.h"
+
+#include "plugin/information_schema_dictionary/information_schema.h"
+
+#include "plugin/information_schema_dictionary/check_constraints.h"
+#include "plugin/information_schema_dictionary/column_domain_usage.h"
+#include "plugin/information_schema_dictionary/column_privileges.h"
+#include "plugin/information_schema_dictionary/columns.h"
+#include "plugin/information_schema_dictionary/constraint_column_usage.h"
+#include "plugin/information_schema_dictionary/constraint_table_usage.h"
+#include "plugin/information_schema_dictionary/domain_constraints.h"
+#include "plugin/information_schema_dictionary/domains.h"
+#include "plugin/information_schema_dictionary/key_column_usage.h"
+#include "plugin/information_schema_dictionary/parameters.h"
+#include "plugin/information_schema_dictionary/referential_constraints.h"
+#include "plugin/information_schema_dictionary/routines.h"
+#include "plugin/information_schema_dictionary/routine_columns.h"
+#include "plugin/information_schema_dictionary/schemata.h"
+#include "plugin/information_schema_dictionary/table_constraints.h"
+#include "plugin/information_schema_dictionary/table_privileges.h"
+#include "plugin/information_schema_dictionary/tables.h"
+#include "plugin/information_schema_dictionary/view_column_usage.h"
+#include "plugin/information_schema_dictionary/view_table_usage.h"
+#include "plugin/information_schema_dictionary/views.h"
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_H */

=== added file 'plugin/information_schema_dictionary/domain_constraints.cc'
--- plugin/information_schema_dictionary/domain_constraints.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/domain_constraints.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,73 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+DomainConstraints::DomainConstraints() :
+  InformationSchema("DOMAIN_CONSTRAINTS")
+{
+  add_field("CONSTRAINT_CATALOG");
+  add_field("CONSTRAINT_SCHEMA");
+  add_field("CONSTRAINT_NAME");
+  add_field("DOMAIN_CATALOG");
+  add_field("DOMAIN_SCHEMA");
+  add_field("DOMAIN_NAME");
+  add_field("IS_DEFERRABLE");
+  add_field("INITIALLY_DEFERRED");
+}
+
+void DomainConstraints::Generator::fill()
+{
+}
+
+bool DomainConstraints::Generator::nextCore()
+{
+  return false;
+}
+
+bool DomainConstraints::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+DomainConstraints::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool DomainConstraints::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/domain_constraints.h'
--- plugin/information_schema_dictionary/domain_constraints.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/domain_constraints.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_DOMAIN_CONSTRAINTS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_DOMAIN_CONSTRAINTS_H
+
+class DomainConstraints : public InformationSchema
+{
+public:
+
+  DomainConstraints();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_DOMAIN_CONSTRAINTS_H */

=== added file 'plugin/information_schema_dictionary/domains.cc'
--- plugin/information_schema_dictionary/domains.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/domains.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,82 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+Domains::Domains() :
+  InformationSchema("DOMAINS")
+{
+  add_field("DOMAIN_CATALOG");
+  add_field("DOMAIN_SCHEMA");
+  add_field("DOMAIN_NAME");
+  add_field("DATA_TYPE");
+  add_field("CHARACTER_MAXIMUM_LENGTH");
+  add_field("CHARACTER_OCTET_LENGTH");
+  add_field("COLLATION_CATALOG");
+  add_field("COLLATION_SCHEMA");
+  add_field("COLLATION_NAME");
+  add_field("CHARACTER_SET_CATALOG");
+  add_field("CHARACTER_SET_SCHEMA");
+  add_field("CHARACTER_SET_NAME");
+  add_field("NUMERIC_PRECISION");
+  add_field("NUMERIC_PRECISION_RADIX");
+  add_field("NUMERIC_SCALE");
+  add_field("DATETIME_PRECISION");
+  add_field("DOMAIN_DEFAULT");
+}
+
+void Domains::Generator::fill()
+{
+}
+
+bool Domains::Generator::nextCore()
+{
+  return false;
+}
+
+bool Domains::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+Domains::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool Domains::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/domains.h'
--- plugin/information_schema_dictionary/domains.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/domains.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_DOMAINS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_DOMAINS_H
+
+class Domains : public InformationSchema
+{
+public:
+
+  Domains();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_DOMAINS_H */

=== added file 'plugin/information_schema_dictionary/information_schema.h'
--- plugin/information_schema_dictionary/information_schema.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/information_schema.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,47 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_INFORMATION_SCHEMA_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_INFORMATION_SCHEMA_H
+
+class InformationSchema : public drizzled::plugin::TableFunction
+{
+public:
+
+  InformationSchema(const char *table_arg) :
+    drizzled::plugin::TableFunction("INFORMATION_SCHEMA", table_arg)
+  { }
+
+  class Generator : public drizzled::plugin::TableFunction::Generator 
+  {
+  public:
+    Generator(drizzled::Field **arg):
+      drizzled::plugin::TableFunction::Generator(arg)
+    { }
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_INFORMATION_SCHEMA_H */

=== added file 'plugin/information_schema_dictionary/key_column_usage.cc'
--- plugin/information_schema_dictionary/key_column_usage.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/key_column_usage.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,73 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+KeyColumnUsage::KeyColumnUsage() :
+  InformationSchema("KEY_COLUMN_USAGE")
+{
+  add_field("CONSTRAINT_CATALOG");
+  add_field("CONSTRAINT_SCHEMA");
+  add_field("CONSTRAINT_NAME");
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("COLUMN_NAME");
+  add_field("ORDINAL_POSITION");
+}
+
+void KeyColumnUsage::Generator::fill()
+{
+}
+
+bool KeyColumnUsage::Generator::nextCore()
+{
+  return false;
+}
+
+bool KeyColumnUsage::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+KeyColumnUsage::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool KeyColumnUsage::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/key_column_usage.h'
--- plugin/information_schema_dictionary/key_column_usage.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/key_column_usage.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_KEY_COLUMN_USAGE_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_KEY_COLUMN_USAGE_H
+
+class KeyColumnUsage : public InformationSchema
+{
+public:
+
+  KeyColumnUsage();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_KEY_COLUMN_USAGE_H */

=== added file 'plugin/information_schema_dictionary/parameters.cc'
--- plugin/information_schema_dictionary/parameters.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/parameters.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,95 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+Parameters::Parameters() :
+  InformationSchema("PARAMETERS")
+{
+  add_field("SPECIFIC_CATALOG");
+  add_field("SPECIFIC_SCHEMA");
+  add_field("SPECIFIC_NAME");
+  add_field("ORDINAL_POSITION");
+  add_field("PARAMETER_MODE");
+  add_field("IS_RESULT");
+  add_field("AS_LOCATOR");
+  add_field("PARAMETER_NAME");
+  add_field("DATA_TYPE");
+  add_field("CHARACTER_MAXIMUM_LENGTH");
+  add_field("CHARACTER_OCTET_LENGTH");
+  add_field("CHARACTER_OCTET_LENGTH");
+  add_field("COLLATION_CATALOG");
+  add_field("COLLATION_SCHEMA");
+  add_field("COLLATION_NAME");
+  add_field("CHARACTER_SET_CATALOG");
+  add_field("CHARACTER_SET_SCHEMA");
+  add_field("CHARACTER_SET_NAME");
+  add_field("NUMERIC_PRECISION");
+  add_field("NUMERIC_PRECISION_RADIX");
+  add_field("NUMERIC_SCALE");
+  add_field("DATETIME_PRECISION");
+  add_field("INTERVAL_TYPE");
+  add_field("INTERVAL_PRECISION");
+  add_field("USER_DEFINED_TYPE_CATALOG");
+  add_field("USER_DEFINED_TYPE_SCHEMA");
+  add_field("USER_DEFINED_TYPE_NAME");
+  add_field("SCOPE_CATALOG");
+  add_field("SCOPE_SCHEMA");
+  add_field("SCOPE_NAME");
+}
+
+void Parameters::Generator::fill()
+{
+}
+
+bool Parameters::Generator::nextCore()
+{
+  return false;
+}
+
+bool Parameters::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+Parameters::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool Parameters::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/parameters.h'
--- plugin/information_schema_dictionary/parameters.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/parameters.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_PARAMETERS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_PARAMETERS_H
+
+class Parameters : public InformationSchema
+{
+public:
+
+  Parameters();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_PARAMETERS_H */

=== added file 'plugin/information_schema_dictionary/plugin.ini'
--- plugin/information_schema_dictionary/plugin.ini	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/plugin.ini	2010-03-17 19:18:40 +0000
@@ -0,0 +1,49 @@
+[plugin]
+title=Information Schema Dictionary
+description= Creates dictionary tables for the ANSI information schema tables
+load_by_default=yes
+sources= 
+  check_constraints.cc
+  column_domain_usage.cc
+  column_privileges.cc
+  columns.cc
+  constraint_column_usage.cc
+  constraint_table_usage.cc
+  dictionary.cc
+  domain_constraints.cc
+  domains.cc
+  key_column_usage.cc
+  parameters.cc
+  referential_constraints.cc
+  routine_columns.cc
+  routines.cc
+  schemata.cc
+  table_constraints.cc
+  table_privileges.cc
+  tables.cc
+  view_column_usage.cc
+  view_table_usage.cc
+  views.cc
+headers=
+  check_constraints.h
+  column_domain_usage.h
+  column_privileges.h
+  columns.h
+  constraint_column_usage.h
+  constraint_table_usage.h
+  dictionary.h
+  domain_constraints.h
+  domains.h
+  information_schema.h
+  key_column_usage.h
+  parameters.h
+  referential_constraints.h
+  routine_columns.h
+  routines.h
+  schemata.h
+  table_constraints.h
+  table_privileges.h
+  tables.h
+  view_column_usage.h
+  view_table_usage.h
+  views.h

=== added file 'plugin/information_schema_dictionary/referential_constraints.cc'
--- plugin/information_schema_dictionary/referential_constraints.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/referential_constraints.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,74 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+ReferentialConstraints::ReferentialConstraints() :
+  InformationSchema("REFERENTIAL_CONSTRAINTS")
+{
+  add_field("CONSTRAINT_CATALOG");
+  add_field("CONSTRAINT_SCHEMA");
+  add_field("CONSTRAINT_NAME");
+  add_field("UNIQUE_CONSTRAINT_CATALOG");
+  add_field("UNIQUE_CONSTRAINT_SCHEMA");
+  add_field("UNIQUE_CONSTRAINT_NAME");
+  add_field("MATCH_OPTION");
+  add_field("UPDATE_RULE");
+  add_field("DELETE_RULE");
+}
+
+void ReferentialConstraints::Generator::fill()
+{
+}
+
+bool ReferentialConstraints::Generator::nextCore()
+{
+  return false;
+}
+
+bool ReferentialConstraints::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+ReferentialConstraints::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool ReferentialConstraints::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/referential_constraints.h'
--- plugin/information_schema_dictionary/referential_constraints.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/referential_constraints.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_REFERENTIAL_CONSTRAINTS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_REFERENTIAL_CONSTRAINTS_H
+
+class ReferentialConstraints : public InformationSchema
+{
+public:
+
+  ReferentialConstraints();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_REFERENTIAL_CONSTRAINTS_H */

=== added file 'plugin/information_schema_dictionary/routine_columns.cc'
--- plugin/information_schema_dictionary/routine_columns.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/routine_columns.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,91 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+RoutineColumns::RoutineColumns() :
+  InformationSchema("ROUTINE_COLUMNS")
+{
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+
+  add_field("COLUMN_NAME");
+  add_field("ORDINAL_POSITION");
+  add_field("COLUMN_DEFAULT");
+
+  add_field("IS_NULLABLE");
+
+  add_field("DATA_TYPE");
+  add_field("CHARACTER_MAXIMUM_LENGTH");
+  add_field("CHARACTER_OCTET_LENGTH");
+  add_field("NUMERIC_PRECISION");
+  add_field("NUMERIC_PRECISION_RADIX");
+  add_field("NUMERIC_SCALE");
+  add_field("DATETIME_PRECISION");
+  add_field("CHARACTER_SET_CATALOG");
+  add_field("CHARACTER_SET_SCHEMA");
+  add_field("CHARACTER_SET_NAME");
+  add_field("COLLATION_CATALOG");
+  add_field("COLLATION_SCHEMA");
+  add_field("COLLATION_NAME");
+  add_field("DOMAIN_CATALOG");
+  add_field("DOMAIN_SCHEMA");
+  add_field("DOMAIN_NAME");
+}
+
+void RoutineColumns::Generator::fill()
+{
+}
+
+bool RoutineColumns::Generator::nextCore()
+{
+  return false;
+}
+
+bool RoutineColumns::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+RoutineColumns::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool RoutineColumns::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/routine_columns.h'
--- plugin/information_schema_dictionary/routine_columns.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/routine_columns.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_ROUTINE_COLUMNS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_ROUTINE_COLUMNS_H
+
+class RoutineColumns : public InformationSchema
+{
+public:
+
+  RoutineColumns();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_ROUTINE_COLUMNS_H */

=== added file 'plugin/information_schema_dictionary/routines.cc'
--- plugin/information_schema_dictionary/routines.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/routines.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,135 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+Routines::Routines() :
+  InformationSchema("ROUTINES")
+{
+  add_field("SPECIFIC_CATALOG");
+  add_field("SPECIFIC_SCHEMA");
+  add_field("SPECIFIC_NAME");
+
+  add_field("ROUTINE_CATALOG");
+  add_field("ROUTINE_SCHEMA");
+  add_field("ROUTINE_NAME");
+
+  add_field("MODULE_CATALOG");
+  add_field("MODULE_SCHEMA");
+  add_field("MODULE_NAME");
+
+  add_field("UDT_CATALOG");
+  add_field("UDT_SCHEMA");
+  add_field("UDT_NAME");
+
+  add_field("DATA_TYPE");
+  add_field("CHARACTER_MAXIMUM_LENGTH");
+  add_field("CHARACTER_OCTET_LENGTH");
+
+  add_field("COLLATION_CATALOG");
+  add_field("COLLATION_SCHEMA");
+  add_field("COLLATION_NAME");
+
+  add_field("CHARACTER_SET_CATALOG");
+  add_field("CHARACTER_SET_SCHEMA");
+  add_field("CHARACTER_SET_NAME");
+
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+
+  add_field("NUMERIC_PRECISION");
+  add_field("NUMERIC_PRECISION_RADIX");
+  add_field("NUMERIC_SCALE");
+
+  add_field("DATETIME_PRECISION");
+
+  add_field("INTERVAL_TYPE");
+  add_field("INTERVAL_PRECISION");
+
+  add_field("TYPE_UDT_CATALOG");
+  add_field("TYPE_UDT_SCHEMA");
+  add_field("TYPE_UDT_NAME");
+
+  add_field("SCOPE_CATALOG");
+  add_field("SCOPE_SCHEMA");
+  add_field("SCOPE_NAME");
+
+  add_field("MAXIMUM_CARDINALITY");
+  add_field("DTD_IDENTIFIER");
+
+  add_field("ROUTINE_BODY");
+  add_field("ROUTINE_DEFINITION");
+
+  add_field("EXTERNAL_NAME");
+  add_field("EXTERNAL_LANGUAGE");
+
+  add_field("PARAMETER_STYLE");
+  add_field("IS_DETERMINISTIC");
+
+  add_field("SQL_DATA_ACCESS");
+  add_field("IS_NULL_CALL");
+  add_field("SQL_PATH");
+  add_field("SCHEMA_LEVEL_ROUTINE");
+  add_field("MAX_DYNAMIC_RESULT_SETS");
+  add_field("IS_USER_DEFINED_CAST");
+  add_field("IS_IMPLICITLY_INVOCABLE");
+  add_field("CREATED");
+  add_field("LAST_ALTERED");
+}
+
+void Routines::Generator::fill()
+{
+}
+
+bool Routines::Generator::nextCore()
+{
+  return false;
+}
+
+bool Routines::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+Routines::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool Routines::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/routines.h'
--- plugin/information_schema_dictionary/routines.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/routines.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_ROUTINES_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_ROUTINES_H
+
+class Routines : public InformationSchema
+{
+public:
+
+  Routines();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_ROUTINES_H */

=== added file 'plugin/information_schema_dictionary/schemata.cc'
--- plugin/information_schema_dictionary/schemata.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/schemata.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,71 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+Schemata::Schemata() :
+  InformationSchema("SCHEMATA")
+{
+  add_field("CATALOG_NAME");
+  add_field("SCHEMA_NAME");
+  add_field("SCHEMA_OWNER");
+  add_field("DEFAULT_CHARACTER_SET_CATALOG");
+  add_field("DEFAULT_CHARACTER_SET_SCHEMA");
+  add_field("DEFAULT_CHARACTER_SET_NAME");
+}
+
+void Schemata::Generator::fill()
+{
+}
+
+bool Schemata::Generator::nextCore()
+{
+  return false;
+}
+
+bool Schemata::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+Schemata::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool Schemata::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/schemata.h'
--- plugin/information_schema_dictionary/schemata.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/schemata.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_SCHEMATA_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_SCHEMATA_H
+
+class Schemata : public InformationSchema
+{
+public:
+
+  Schemata();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_SCHEMATA_H */

=== added file 'plugin/information_schema_dictionary/table_constraints.cc'
--- plugin/information_schema_dictionary/table_constraints.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/table_constraints.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,74 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+TableConstraints::TableConstraints() :
+  InformationSchema("TABLE_CONSTRAINTS")
+{
+  add_field("CONSTRAINT_CATALOG");
+  add_field("CONSTRAINT_SCHEMA");
+  add_field("CONSTRAINT_NAME");
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("CONSTRAINT_TYPE");
+  add_field("IS_DEFERRABLE");
+  add_field("INITIALLY_DEFERRED");
+}
+
+void TableConstraints::Generator::fill()
+{
+}
+
+bool TableConstraints::Generator::nextCore()
+{
+  return false;
+}
+
+bool TableConstraints::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+TableConstraints::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool TableConstraints::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/table_constraints.h'
--- plugin/information_schema_dictionary/table_constraints.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/table_constraints.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLE_CONSTRAINTS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLE_CONSTRAINTS_H
+
+class TableConstraints : public InformationSchema
+{
+public:
+
+  TableConstraints();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLE_CONSTRAINTS_H */

=== added file 'plugin/information_schema_dictionary/table_privileges.cc'
--- plugin/information_schema_dictionary/table_privileges.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/table_privileges.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,73 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+TablePriviledges::TablePriviledges() :
+  InformationSchema("TABLE_PRIVILEDGES")
+{
+  add_field("GRANTOR");
+  add_field("GRANTEE");
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("COLUMN_NAME");
+  add_field("PRIVILEGE_TYPE");
+  add_field("IS_GRANTABLE");
+}
+
+void TablePriviledges::Generator::fill()
+{
+}
+
+bool TablePriviledges::Generator::nextCore()
+{
+  return false;
+}
+
+bool TablePriviledges::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+TablePriviledges::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool TablePriviledges::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/table_privileges.h'
--- plugin/information_schema_dictionary/table_privileges.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/table_privileges.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLE_PRIVILEGES_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLE_PRIVILEGES_H
+
+class TablePriviledges : public InformationSchema
+{
+public:
+
+  TablePriviledges();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLE_PRIVILEGES_H */

=== added file 'plugin/information_schema_dictionary/tables.cc'
--- plugin/information_schema_dictionary/tables.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/tables.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,69 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+Tables::Tables() :
+  InformationSchema("TABLES")
+{
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("TABLE_TYPE");
+}
+
+void Tables::Generator::fill()
+{
+}
+
+bool Tables::Generator::nextCore()
+{
+  return false;
+}
+
+bool Tables::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+Tables::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool Tables::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/tables.h'
--- plugin/information_schema_dictionary/tables.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/tables.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLES_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLES_H
+
+class Tables : public InformationSchema
+{
+public:
+
+  Tables();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_TABLES_H */

=== added directory 'plugin/information_schema_dictionary/tests'
=== added directory 'plugin/information_schema_dictionary/tests/r'
=== added file 'plugin/information_schema_dictionary/tests/r/show_create_table.result'
--- plugin/information_schema_dictionary/tests/r/show_create_table.result	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/tests/r/show_create_table.result	2010-03-17 19:18:40 +0000
@@ -0,0 +1,330 @@
+use information_schema;
+SHOW CREATE TABLE `CHECK_CONSTRAINTS`;
+Table	Create Table
+CHECK_CONSTRAINTS	CREATE TABLE `check_constraints` (
+  `CONSTRAINT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_NAME` varchar(64) NOT NULL DEFAULT '',
+  `CHECK_CLAUSE` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `COLUMNS`;
+Table	Create Table
+COLUMNS	CREATE TABLE `columns` (
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `ORDINAL_POSITION` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_DEFAULT` varchar(64) NOT NULL DEFAULT '',
+  `IS_NULLABLE` varchar(64) NOT NULL DEFAULT '',
+  `DATA_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_MAXIMUM_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_OCTET_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION_RADIX` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_SCALE` varchar(64) NOT NULL DEFAULT '',
+  `DATETIME_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_NAME` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `COLUMN_DOMAIN_USAGE`;
+Table	Create Table
+COLUMN_DOMAIN_USAGE	CREATE TABLE `column_domain_usage` (
+  `DOMAIN_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `COLUMN_PRIVILEGES`;
+Table	Create Table
+COLUMN_PRIVILEGES	CREATE TABLE `column_privileges` (
+  `GRANTOR` varchar(64) NOT NULL DEFAULT '',
+  `GRANTEE` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `PRIVILEGE_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `IS_GRANTABLE` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `CONSTRAINT_COLUMN_USAGE`;
+Table	Create Table
+CONSTRAINT_COLUMN_USAGE	CREATE TABLE `constraint_column_usage` (
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `CONSTRAINT_TABLE_USAGE`;
+Table	Create Table
+CONSTRAINT_TABLE_USAGE	CREATE TABLE `constraint_table_usage` (
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `DOMAINS`;
+Table	Create Table
+DOMAINS	CREATE TABLE `domains` (
+  `DOMAIN_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `DATA_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_MAXIMUM_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_OCTET_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_NAME` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_NAME` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION_RADIX` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_SCALE` varchar(64) NOT NULL DEFAULT '',
+  `DATETIME_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_DEFAULT` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `DOMAIN_CONSTRAINTS`;
+Table	Create Table
+DOMAIN_CONSTRAINTS	CREATE TABLE `domain_constraints` (
+  `CONSTRAINT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_NAME` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `IS_DEFERRABLE` varchar(64) NOT NULL DEFAULT '',
+  `INITIALLY_DEFERRED` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `KEY_COLUMN_USAGE`;
+Table	Create Table
+KEY_COLUMN_USAGE	CREATE TABLE `key_column_usage` (
+  `CONSTRAINT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_NAME` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `ORDINAL_POSITION` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `PARAMETERS`;
+Table	Create Table
+PARAMETERS	CREATE TABLE `parameters` (
+  `SPECIFIC_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `SPECIFIC_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `SPECIFIC_NAME` varchar(64) NOT NULL DEFAULT '',
+  `ORDINAL_POSITION` varchar(64) NOT NULL DEFAULT '',
+  `PARAMETER_MODE` varchar(64) NOT NULL DEFAULT '',
+  `IS_RESULT` varchar(64) NOT NULL DEFAULT '',
+  `AS_LOCATOR` varchar(64) NOT NULL DEFAULT '',
+  `PARAMETER_NAME` varchar(64) NOT NULL DEFAULT '',
+  `DATA_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_MAXIMUM_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_OCTET_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_OCTET_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_NAME` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_NAME` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION_RADIX` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_SCALE` varchar(64) NOT NULL DEFAULT '',
+  `DATETIME_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `INTERVAL_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `INTERVAL_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `USER_DEFINED_TYPE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `USER_DEFINED_TYPE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `USER_DEFINED_TYPE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `SCOPE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `SCOPE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `SCOPE_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `REFERENTIAL_CONSTRAINTS`;
+Table	Create Table
+REFERENTIAL_CONSTRAINTS	CREATE TABLE `referential_constraints` (
+  `CONSTRAINT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_NAME` varchar(64) NOT NULL DEFAULT '',
+  `UNIQUE_CONSTRAINT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `UNIQUE_CONSTRAINT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `UNIQUE_CONSTRAINT_NAME` varchar(64) NOT NULL DEFAULT '',
+  `MATCH_OPTION` varchar(64) NOT NULL DEFAULT '',
+  `UPDATE_RULE` varchar(64) NOT NULL DEFAULT '',
+  `DELETE_RULE` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `ROUTINES`;
+Table	Create Table
+ROUTINES	CREATE TABLE `routines` (
+  `SPECIFIC_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `SPECIFIC_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `SPECIFIC_NAME` varchar(64) NOT NULL DEFAULT '',
+  `ROUTINE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `ROUTINE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `ROUTINE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `MODULE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `MODULE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `MODULE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `UDT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `UDT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `UDT_NAME` varchar(64) NOT NULL DEFAULT '',
+  `DATA_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_MAXIMUM_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_OCTET_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_NAME` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_NAME` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION_RADIX` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_SCALE` varchar(64) NOT NULL DEFAULT '',
+  `DATETIME_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `INTERVAL_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `INTERVAL_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `TYPE_UDT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TYPE_UDT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TYPE_UDT_NAME` varchar(64) NOT NULL DEFAULT '',
+  `SCOPE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `SCOPE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `SCOPE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `MAXIMUM_CARDINALITY` varchar(64) NOT NULL DEFAULT '',
+  `DTD_IDENTIFIER` varchar(64) NOT NULL DEFAULT '',
+  `ROUTINE_BODY` varchar(64) NOT NULL DEFAULT '',
+  `ROUTINE_DEFINITION` varchar(64) NOT NULL DEFAULT '',
+  `EXTERNAL_NAME` varchar(64) NOT NULL DEFAULT '',
+  `EXTERNAL_LANGUAGE` varchar(64) NOT NULL DEFAULT '',
+  `PARAMETER_STYLE` varchar(64) NOT NULL DEFAULT '',
+  `IS_DETERMINISTIC` varchar(64) NOT NULL DEFAULT '',
+  `SQL_DATA_ACCESS` varchar(64) NOT NULL DEFAULT '',
+  `IS_NULL_CALL` varchar(64) NOT NULL DEFAULT '',
+  `SQL_PATH` varchar(64) NOT NULL DEFAULT '',
+  `SCHEMA_LEVEL_ROUTINE` varchar(64) NOT NULL DEFAULT '',
+  `MAX_DYNAMIC_RESULT_SETS` varchar(64) NOT NULL DEFAULT '',
+  `IS_USER_DEFINED_CAST` varchar(64) NOT NULL DEFAULT '',
+  `IS_IMPLICITLY_INVOCABLE` varchar(64) NOT NULL DEFAULT '',
+  `CREATED` varchar(64) NOT NULL DEFAULT '',
+  `LAST_ALTERED` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `ROUTINE_COLUMNS`;
+Table	Create Table
+ROUTINE_COLUMNS	CREATE TABLE `routine_columns` (
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `ORDINAL_POSITION` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_DEFAULT` varchar(64) NOT NULL DEFAULT '',
+  `IS_NULLABLE` varchar(64) NOT NULL DEFAULT '',
+  `DATA_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_MAXIMUM_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_OCTET_LENGTH` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_PRECISION_RADIX` varchar(64) NOT NULL DEFAULT '',
+  `NUMERIC_SCALE` varchar(64) NOT NULL DEFAULT '',
+  `DATETIME_PRECISION` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CHARACTER_SET_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `COLLATION_NAME` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `DOMAIN_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `SCHEMATA`;
+Table	Create Table
+SCHEMATA	CREATE TABLE `schemata` (
+  `CATALOG_NAME` varchar(64) NOT NULL DEFAULT '',
+  `SCHEMA_NAME` varchar(64) NOT NULL DEFAULT '',
+  `SCHEMA_OWNER` varchar(64) NOT NULL DEFAULT '',
+  `DEFAULT_CHARACTER_SET_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `DEFAULT_CHARACTER_SET_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `DEFAULT_CHARACTER_SET_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `TABLES`;
+Table	Create Table
+TABLES	CREATE TABLE `tables` (
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_TYPE` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `TABLE_CONSTRAINTS`;
+Table	Create Table
+TABLE_CONSTRAINTS	CREATE TABLE `table_constraints` (
+  `CONSTRAINT_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_NAME` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `CONSTRAINT_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `IS_DEFERRABLE` varchar(64) NOT NULL DEFAULT '',
+  `INITIALLY_DEFERRED` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `TABLE_PRIVILEDGES`;
+Table	Create Table
+TABLE_PRIVILEDGES	CREATE TABLE `table_priviledges` (
+  `GRANTOR` varchar(64) NOT NULL DEFAULT '',
+  `GRANTEE` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `PRIVILEGE_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `IS_GRANTABLE` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `VIEWS`;
+Table	Create Table
+VIEWS	CREATE TABLE `views` (
+  `VIEW_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `VIEW_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `VIEW_NAME` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `VIEW_COLUMN_USAGE`;
+Table	Create Table
+VIEW_COLUMN_USAGE	CREATE TABLE `view_column_usage` (
+  `VIEW_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `VIEW_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `VIEW_NAME` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `COLUMN_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+SHOW CREATE TABLE `VIEW_TABLE_USAGE`;
+Table	Create Table
+VIEW_TABLE_USAGE	CREATE TABLE `view_table_usage` (
+  `TABLE_CATALOG` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `VIEW_DEFINITION` varchar(64) NOT NULL DEFAULT '',
+  `CHECK_OPTION` varchar(64) NOT NULL DEFAULT '',
+  `IS_UPDATABLE` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine

=== added file 'plugin/information_schema_dictionary/tests/r/slap.result'
--- plugin/information_schema_dictionary/tests/r/slap.result	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/tests/r/slap.result	2010-03-17 19:18:40 +0000
@@ -0,0 +1,2 @@
+CREATE SCHEMA drizzleslap;
+DROP SCHEMA drizzleslap;

=== added directory 'plugin/information_schema_dictionary/tests/t'
=== added file 'plugin/information_schema_dictionary/tests/t/show_create_table.test'
--- plugin/information_schema_dictionary/tests/t/show_create_table.test	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/tests/t/show_create_table.test	2010-03-17 19:18:40 +0000
@@ -0,0 +1,22 @@
+use information_schema;
+
+SHOW CREATE TABLE `CHECK_CONSTRAINTS`;
+SHOW CREATE TABLE `COLUMNS`;
+SHOW CREATE TABLE `COLUMN_DOMAIN_USAGE`;
+SHOW CREATE TABLE `COLUMN_PRIVILEGES`;
+SHOW CREATE TABLE `CONSTRAINT_COLUMN_USAGE`;
+SHOW CREATE TABLE `CONSTRAINT_TABLE_USAGE`;
+SHOW CREATE TABLE `DOMAINS`;
+SHOW CREATE TABLE `DOMAIN_CONSTRAINTS`;
+SHOW CREATE TABLE `KEY_COLUMN_USAGE`;
+SHOW CREATE TABLE `PARAMETERS`;
+SHOW CREATE TABLE `REFERENTIAL_CONSTRAINTS`;
+SHOW CREATE TABLE `ROUTINES`;
+SHOW CREATE TABLE `ROUTINE_COLUMNS`;
+SHOW CREATE TABLE `SCHEMATA`;
+SHOW CREATE TABLE `TABLES`;
+SHOW CREATE TABLE `TABLE_CONSTRAINTS`;
+SHOW CREATE TABLE `TABLE_PRIVILEDGES`;
+SHOW CREATE TABLE `VIEWS`;
+SHOW CREATE TABLE `VIEW_COLUMN_USAGE`;
+SHOW CREATE TABLE `VIEW_TABLE_USAGE`;

=== added file 'plugin/information_schema_dictionary/tests/t/slap.test'
--- plugin/information_schema_dictionary/tests/t/slap.test	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/tests/t/slap.test	2010-03-17 19:18:40 +0000
@@ -0,0 +1,28 @@
+# Drizzle's information_schema
+
+# Slap tests for concurrency
+CREATE SCHEMA drizzleslap;
+
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.CHECK_CONSTRAINTS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.COLUMNS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.COLUMN_DOMAIN_USAGE" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.COLUMN_PRIVILEGES" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.CONSTRAINT_COLUMN_USAGE" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.CONSTRAINT_TABLE_USAGE" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.DOMAINS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.DOMAIN_CONSTRAINTS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.KEY_COLUMN_USAGE" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.PARAMETERS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.REFERENTIAL_CONSTRAINTS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.ROUTINES" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.ROUTINE_COLUMNS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.SCHEMATA" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.TABLES" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.TABLE_CONSTRAINTS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.TABLE_PRIVILEDGES" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.VIEWS" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.VIEW_COLUMN_USAGE" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from information_schema.VIEW_TABLE_USAGE" --delimiter=";"
+
+
+DROP SCHEMA drizzleslap;

=== added file 'plugin/information_schema_dictionary/view_column_usage.cc'
--- plugin/information_schema_dictionary/view_column_usage.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/view_column_usage.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,74 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+ViewColumnUsage::ViewColumnUsage() :
+  InformationSchema("VIEW_COLUMN_USAGE")
+{
+  add_field("VIEW_CATALOG");
+  add_field("VIEW_SCHEMA");
+  add_field("VIEW_NAME");
+
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+
+  add_field("COLUMN_NAME");
+}
+
+void ViewColumnUsage::Generator::fill()
+{
+}
+
+bool ViewColumnUsage::Generator::nextCore()
+{
+  return false;
+}
+
+bool ViewColumnUsage::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+ViewColumnUsage::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool ViewColumnUsage::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/view_column_usage.h'
--- plugin/information_schema_dictionary/view_column_usage.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/view_column_usage.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEW_COLUMN_USAGE_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEW_COLUMN_USAGE_H
+
+class ViewColumnUsage : public InformationSchema
+{
+public:
+
+  ViewColumnUsage();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEW_COLUMN_USAGE_H */

=== added file 'plugin/information_schema_dictionary/view_table_usage.cc'
--- plugin/information_schema_dictionary/view_table_usage.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/view_table_usage.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,72 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+ViewTableUsage::ViewTableUsage() :
+  InformationSchema("VIEW_TABLE_USAGE")
+{
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+
+  add_field("VIEW_DEFINITION");
+  add_field("CHECK_OPTION");
+  add_field("IS_UPDATABLE");
+}
+
+void ViewTableUsage::Generator::fill()
+{
+}
+
+bool ViewTableUsage::Generator::nextCore()
+{
+  return false;
+}
+
+bool ViewTableUsage::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+ViewTableUsage::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool ViewTableUsage::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/view_table_usage.h'
--- plugin/information_schema_dictionary/view_table_usage.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/view_table_usage.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEW_TABLE_USAGE_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEW_TABLE_USAGE_H
+
+class ViewTableUsage : public InformationSchema
+{
+public:
+
+  ViewTableUsage();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEW_TABLE_USAGE_H */

=== added file 'plugin/information_schema_dictionary/views.cc'
--- plugin/information_schema_dictionary/views.cc	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/views.cc	2010-03-17 19:18:40 +0000
@@ -0,0 +1,72 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/information_schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+Views::Views() :
+  InformationSchema("VIEWS")
+{
+  add_field("VIEW_CATALOG");
+  add_field("VIEW_SCHEMA");
+  add_field("VIEW_NAME");
+
+  add_field("TABLE_CATALOG");
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+}
+
+void Views::Generator::fill()
+{
+}
+
+bool Views::Generator::nextCore()
+{
+  return false;
+}
+
+bool Views::Generator::next()
+{
+  while (not nextCore())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+Views::Generator::Generator(drizzled::Field **arg) :
+  InformationSchema::Generator(arg),
+  is_primed(false)
+{
+}
+
+bool Views::Generator::populate()
+{
+  if (not next())
+    return false;
+
+  fill();
+
+  return true;
+}

=== added file 'plugin/information_schema_dictionary/views.h'
--- plugin/information_schema_dictionary/views.h	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/views.h	2010-03-17 19:18:40 +0000
@@ -0,0 +1,50 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEWS_H
+#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEWS_H
+
+class Views : public InformationSchema
+{
+public:
+
+  Views();
+
+  class Generator : public InformationSchema::Generator 
+  {
+    bool is_primed;
+    void fill();
+    bool nextCore();
+    bool next();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+
+};
+
+#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_VIEWS_H */

=== modified file 'plugin/schema_dictionary/tests/r/data_dictionary.result'
--- plugin/schema_dictionary/tests/r/data_dictionary.result	2010-03-16 23:42:10 +0000
+++ plugin/schema_dictionary/tests/r/data_dictionary.result	2010-03-17 19:18:40 +0000
@@ -217,6 +217,255 @@
 #
 #
 #
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
 SELECT count(*) FROM REFERENTIAL_CONSTRAINTS;
 count(*)
 #

=== modified file 'tests/r/data_dictionary_like_info.result'
--- tests/r/data_dictionary_like_info.result	2010-03-16 23:42:10 +0000
+++ tests/r/data_dictionary_like_info.result	2010-03-17 19:18:40 +0000
@@ -247,12 +247,12 @@
 table_name	column_name
 SELECT MAX(table_name) FROM data_dictionary.tables;
 MAX(table_name)
-TABLE_DEFINITION_CACHE
+VIEW_TABLE_USAGE
 SELECT table_name from data_dictionary.tables
 WHERE table_name=(SELECT MAX(table_name)
 FROM data_dictionary.tables);
 table_name
-TABLE_DEFINITION_CACHE
+VIEW_TABLE_USAGE
 create table t1 (f1 int);
 create table t2 (f1 int, f2 int);
 select table_name from data_dictionary.tables

=== modified file 'tests/r/information_schema.result'
Binary files tests/r/information_schema.result and tests/r/information_schema.result differ
